@@ -1,9 +1,9 @@
 package Devel::Examine::Subs::Engine;
-use 5.012;
+use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.54';
+our $VERSION = '1.55';
 
 use Carp;
 use Data::Dumper;
@@ -382,7 +382,7 @@ sub inject_after {
 
             my $sub = $subs_hash->{$_};
 
-            my $num_injects = $p->{injects} // 1;
+            my $num_injects = defined $p->{injects} ? $p->{injects} : 1;
 
             push @processed, $sub->name;
 
