@@ -1,9 +1,9 @@
 package Devel::Examine::Subs::Preprocessor;
-use 5.012;
+use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.54';
+our $VERSION = '1.55';
 
 use Carp;
 use Data::Dumper;
@@ -176,7 +176,11 @@ sub inject {
 
             my $is_multi = 0;
 
-            while (my ($i, $e) = each @file_contents){
+            my $i = -1;
+
+            for my $e (@file_contents){
+
+                $i++;
 
                 if ($e =~ /^\n/){
                     push @new_file, "\n";
@@ -232,7 +236,7 @@ sub replace {
 
         my $p = shift;
         my $exec = $p->{exec};
-        my $limit = $p->{limit} // -1;
+        my $limit = defined $p->{limit} ? $p->{limit} : -1;
 
         my @file = @{ $p->{file_contents} };
 
